/// <reference types="node" resolution-mode="require"/>
import type { Connection, SendOptions, Transaction, TransactionInstruction } from '@solana/web3.js';
import { Keypair, PublicKey } from '@solana/web3.js';
import type { Network, SignAndSendSigner, SignOnlySigner, Signer, UnsignedTransaction } from '@wormhole-foundation/sdk-connect';
import type { SolanaChains } from './types.js';
import type { SolanaUnsignedTransaction } from './unsignedTransaction.js';
export declare function getSolanaSigner(rpc: Connection, privateKey: string): Promise<Signer>;
export declare function getSolanaSignAndSendSigner(rpc: Connection, privateKey: string | Keypair, opts?: {
    debug?: boolean;
    priorityFeePercentile?: number;
    sendOpts?: SendOptions;
}): Promise<Signer>;
export declare class SolanaSigner<N extends Network, C extends SolanaChains = 'Solana'> implements SignOnlySigner<N, C> {
    private _chain;
    private _keypair;
    private _rpc;
    private _debug;
    constructor(_chain: C, _keypair: Keypair, _rpc: Connection, _debug?: boolean);
    chain(): C;
    address(): string;
    sign(tx: SolanaUnsignedTransaction<N>[]): Promise<Buffer[]>;
}
export declare class SolanaSendSigner<N extends Network, C extends SolanaChains = 'Solana'> implements SignAndSendSigner<N, C> {
    private _rpc;
    private _chain;
    private _keypair;
    private _debug;
    private _priorityFeePercentile;
    private _sendOpts?;
    constructor(_rpc: Connection, _chain: C, _keypair: Keypair, _debug?: boolean, _priorityFeePercentile?: number, _sendOpts?: SendOptions | undefined);
    chain(): C;
    address(): string;
    private retryable;
    signAndSend(tx: UnsignedTransaction[]): Promise<any[]>;
}
export declare function logTxDetails(transaction: Transaction): void;
export declare function createPriorityFeeInstructions(connection: Connection, transaction: Transaction, lockedWritableAccounts?: PublicKey[], feePercentile?: number, minPriorityFee?: number): Promise<TransactionInstruction[]>;
export declare function determineComputeBudget(connection: Connection, transaction: Transaction, lockedWritableAccounts?: PublicKey[], feePercentile?: number, minPriorityFee?: number): Promise<TransactionInstruction[]>;
//# sourceMappingURL=signer.d.ts.map